function dRUv = lyngby_nn_edru(V, W, Reg)

% lyngby_nn_edru       - First order derivative, Regularization
%
%       function dRUv = lyngby_nn_edru(V, W, Reg)
%
%       Input:  V     Input weights
%               W     Output weights
%               Reg   Regularization
%
%       Output: dRUv   Derivative in a vectorized matrix

% cvs : $Id: lyngby_nn_edru.m,v 1.2 1998/03/18 13:19:00 fnielsen Exp $
%       $Revision: 1.2 $

      
    dRUv = Reg .* [V(:) ; W(:)];











